==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/poshuku/plugins/wyfv/leechcraft_poshuku_wyfv_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::RelatedItem</name>
    <message>
        <location filename="relateditem.cpp" line="108"/>
        <source>Failed to load</source>
        <translation>Failed to load</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::RelatedWidget</name>
    <message>
        <location filename="relatedwidget.cpp" line="52"/>
        <source>Related videos</source>
        <translation>Related videos</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::WYFV</name>
    <message>
        <location filename="wyfv.cpp" line="66"/>
        <source>Replaces Flash-based video player to play video without Flash installed.</source>
        <translation>Replaces Flash-based video player to play video without Flash installed.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::YoutubePlayer</name>
    <message>
        <location filename="youtubeplayer.cpp" line="221"/>
        <source>This format is unavailable, please select another one.</source>
        <translation>This format is unavailable, please select another one.</translation>
    </message>
</context>
<context>
    <name>Player</name>
    <message>
        <location filename="player.ui" line="28"/>
        <source>Related...</source>
        <translation>Related...</translation>
    </message>
</context>
<context>
    <name>RelatedItem</name>
    <message>
        <location filename="relateditem.ui" line="130"/>
        <source>%v</source>
        <translation>%v</translation>
    </message>
</context>
<context>
    <name>poshukuwyfvsettings</name>
    <message>
        <location filename="dummyfile.cpp" line="2"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="3"/>
        <source>WYFV</source>
        <translation>WYFV</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="4"/>
        <source>Enable for these sites:</source>
        <translation>Enable for these sites:</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="5"/>
        <source>YouTube</source>
        <translation>YouTube</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="6"/>
        <source>Vkontakte.ru</source>
        <translation>Vkontakte.ru</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.65.tar.bz2: leechcraft-0.4.65/src/plugins/poshuku/plugins/wyfv/leechcraft_poshuku_wyfv_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::RelatedItem</name>
    <message>
        <location filename="relateditem.cpp" line="108"/>
        <source>Failed to load</source>
        <translation>Failed to load</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::RelatedWidget</name>
    <message>
        <location filename="relatedwidget.cpp" line="52"/>
        <source>Related videos</source>
        <translation>Related videos</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::WYFV</name>
    <message>
        <location filename="wyfv.cpp" line="71"/>
        <source>Replaces Flash-based video player to play video without Flash installed.</source>
        <translation>Replaces Flash-based video player to play video without Flash installed.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::WYFV::YoutubePlayer</name>
    <message>
        <location filename="youtubeplayer.cpp" line="221"/>
        <source>This format is unavailable, please select another one.</source>
        <translation>This format is unavailable, please select another one.</translation>
    </message>
</context>
<context>
    <name>Player</name>
    <message>
        <location filename="player.ui" line="28"/>
        <source>Related...</source>
        <translation>Related...</translation>
    </message>
</context>
<context>
    <name>RelatedItem</name>
    <message>
        <location filename="relateditem.ui" line="130"/>
        <source>%v</source>
        <translation>%v</translation>
    </message>
</context>
<context>
    <name>poshukuwyfvsettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <source>WYFV</source>
        <translation>WYFV</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Enable for these sites:</source>
        <translation>Enable for these sites:</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>YouTube</source>
        <translation>YouTube</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Vkontakte.ru</source>
        <translation>Vkontakte.ru</translation>
    </message>
</context>
</TS>
